Index: trunk/include/regfi.h
===================================================================
--- trunk/include/regfi.h	(revision 202)
+++ trunk/include/regfi.h	(revision 203)
@@ -553,5 +553,5 @@
    */
   bool     data_in_offset;
-} REGFI_VK_REC;
+} REGFI_VK;
 
 
@@ -593,5 +593,5 @@
   /** The magic number for this record (should be "sk") */
   uint8_t  magic[REGFI_CELL_MAGIC_SIZE];
-} REGFI_SK_REC;
+} REGFI_SK;
 
 
@@ -599,5 +599,5 @@
  * @ingroup regfiBase
  */
-typedef struct
+typedef struct _regfi_nk_rec
 {
   /** Real offset of this record's cell in the file */
@@ -688,5 +688,5 @@
   /** Virtual offset of SK record */
   uint32_t sk_off;
-} REGFI_NK_REC;
+} REGFI_NK;
 
 
@@ -719,29 +719,4 @@
 typedef struct _regfi_file
 {
-  /* Run-time information */
-  /************************/
-  /* Functions for accessing the file */
-  REGFI_RAW_FILE* cb;
-
-  /* Mutex for all cb access.  This is done to prevent one thread from moving
-   * the file offset while another thread is in the middle of a multi-read
-   * parsing transaction */
-  pthread_mutex_t cb_lock;
-
-  /* For sanity checking (not part of the registry header) */
-  uint32_t file_length;
-
-  /* Metadata about hbins */
-  range_list* hbins;
-
-  /* Multiple read access allowed, write access is exclusive */
-  pthread_rwlock_t hbins_lock;
-
-  /* SK record cached since they're repeatedly reused */
-  lru_cache* sk_cache;
-
-  /* Need exclusive access for LRUs, since lookups make changes */
-  pthread_mutex_t sk_lock;
-
   /* Data parsed from file header */
   /********************************/
@@ -794,4 +769,30 @@
   uint8_t reserved2[REGFI_REGF_RESERVED2_SIZE];
 
+
+  /* Run-time information */
+  /************************/
+  /* Functions for accessing the file */
+  REGFI_RAW_FILE* cb;
+
+  /* Mutex for all cb access.  This is done to prevent one thread from moving
+   * the file offset while another thread is in the middle of a multi-read
+   * parsing transaction */
+  pthread_mutex_t cb_lock;
+
+  /* For sanity checking (not part of the registry header) */
+  uint32_t file_length;
+
+  /* Metadata about hbins */
+  range_list* hbins;
+
+  /* Multiple read access allowed, write access is exclusive */
+  pthread_rwlock_t hbins_lock;
+
+  /* SK record cached since they're repeatedly reused */
+  lru_cache* sk_cache;
+
+  /* Need exclusive access for LRUs, since lookups make changes */
+  pthread_mutex_t sk_lock;
+
 } REGFI_FILE;
 
@@ -809,5 +810,5 @@
 
   /** The current key */
-  REGFI_NK_REC* cur_key;
+  REGFI_NK* cur_key;
 
   /** The encoding that all strings are converted to as set during iterator
@@ -826,5 +827,5 @@
 typedef struct _regfi_iter_position
 {
-  REGFI_NK_REC* nk;
+  REGFI_NK* nk;
   uint32_t cur_subkey;
   /* We could store a cur_value here as well, but didn't see 
@@ -939,5 +940,5 @@
 /** Frees a record previously returned by one of the API functions.
  *
  * Can be used to free REGFI_NK_REC, REGFI_VK_REC, REGFI_SK_REC, REGFI_DATA, and
  * REGFI_CLASSNAME records.
  *
@@ -1070,5 +1071,5 @@
  */
 _EXPORT
-const REGFI_NK_REC* regfi_iterator_cur_key(REGFI_ITERATOR* i);
+const REGFI_NK* regfi_iterator_cur_key(REGFI_ITERATOR* i);
 
 
@@ -1082,5 +1083,5 @@
  */
 _EXPORT
-const REGFI_SK_REC* regfi_iterator_cur_sk(REGFI_ITERATOR* i);
+const REGFI_SK* regfi_iterator_cur_sk(REGFI_ITERATOR* i);
 
 
@@ -1109,5 +1110,5 @@
  */
 _EXPORT
-const REGFI_NK_REC* regfi_iterator_cur_subkey(REGFI_ITERATOR* i);
+const REGFI_NK* regfi_iterator_cur_subkey(REGFI_ITERATOR* i);
 
 
@@ -1163,5 +1164,5 @@
  */
 _EXPORT
-const REGFI_VK_REC* regfi_iterator_cur_value(REGFI_ITERATOR* i);
+const REGFI_VK* regfi_iterator_cur_value(REGFI_ITERATOR* i);
 
 
@@ -1205,5 +1206,5 @@
 _EXPORT
 const REGFI_CLASSNAME* regfi_iterator_fetch_classname(REGFI_ITERATOR* i, 
-						      const REGFI_NK_REC* key);
+						      const REGFI_NK* key);
 
 
@@ -1220,5 +1221,5 @@
 _EXPORT
 const REGFI_DATA* regfi_iterator_fetch_data(REGFI_ITERATOR* i,
-					    const REGFI_VK_REC* value);
+					    const REGFI_VK* value);
 
 
@@ -1237,5 +1238,5 @@
  */
 _EXPORT
-REGFI_NK_REC* regfi_load_key(REGFI_FILE* file, uint32_t offset, 
+REGFI_NK* regfi_load_key(REGFI_FILE* file, uint32_t offset, 
 			     REGFI_ENCODING output_encoding, 
 			     bool strict);
@@ -1249,5 +1250,5 @@
  */
 _EXPORT
-REGFI_VK_REC* regfi_load_value(REGFI_FILE* file, uint32_t offset, 
+REGFI_VK* regfi_load_value(REGFI_FILE* file, uint32_t offset, 
 			       REGFI_ENCODING output_encoding, 
 			       bool strict);
@@ -1327,5 +1328,5 @@
  */
 _EXPORT
-const REGFI_SK_REC* regfi_load_sk(REGFI_FILE* file, uint32_t offset,
+const REGFI_SK* regfi_load_sk(REGFI_FILE* file, uint32_t offset,
 				  bool strict);
 
@@ -1369,5 +1370,5 @@
  */
 _EXPORT
-REGFI_NK_REC* regfi_parse_nk(REGFI_FILE* file, uint32_t offset,
+REGFI_NK* regfi_parse_nk(REGFI_FILE* file, uint32_t offset,
 			     uint32_t max_size, bool strict);
 
@@ -1391,5 +1392,5 @@
  */
 _EXPORT
-REGFI_VK_REC* regfi_parse_vk(REGFI_FILE* file, uint32_t offset, 
+REGFI_VK* regfi_parse_vk(REGFI_FILE* file, uint32_t offset, 
 			     uint32_t max_size, bool strict);
 
@@ -1402,5 +1403,5 @@
  */
 _EXPORT
-REGFI_SK_REC* regfi_parse_sk(REGFI_FILE* file, uint32_t offset, 
+REGFI_SK* regfi_parse_sk(REGFI_FILE* file, uint32_t offset, 
 			     uint32_t max_size, bool strict);
 
@@ -1469,5 +1470,5 @@
 /*    Private Functions                                                       */
 /******************************************************************************/
-REGFI_NK_REC*         regfi_rootkey(REGFI_FILE* file, 
+REGFI_NK*         regfi_rootkey(REGFI_FILE* file, 
 				    REGFI_ENCODING output_encoding);
 
@@ -1505,6 +1506,6 @@
 void                  regfi_add_message(REGFI_FILE* file, uint16_t msg_type, 
 					const char* fmt, ...);
-REGFI_NK_REC*         regfi_copy_nk(const REGFI_NK_REC* nk);
-REGFI_VK_REC*         regfi_copy_vk(const REGFI_VK_REC* vk);
+REGFI_NK*         regfi_copy_nk(const REGFI_NK* nk);
+REGFI_VK*         regfi_copy_vk(const REGFI_VK* vk);
 _EXPORT
 int32_t               regfi_calc_maxsize(REGFI_FILE* file, uint32_t offset);
@@ -1524,8 +1525,8 @@
 
 _EXPORT
-void regfi_interpret_keyname(REGFI_FILE* file, REGFI_NK_REC* nk, 
+void regfi_interpret_keyname(REGFI_FILE* file, REGFI_NK* nk, 
 			     REGFI_ENCODING output_encoding, bool strict);
 _EXPORT
-void regfi_interpret_valuename(REGFI_FILE* file, REGFI_VK_REC* vk, 
+void regfi_interpret_valuename(REGFI_FILE* file, REGFI_VK* vk, 
 			       REGFI_ENCODING output_encoding, bool strict);
 
@@ -939,5 +940,5 @@
 /** Frees a record previously returned by one of the API functions.
  *
- * Can be used to free REGFI_NK_REC, REGFI_VK_REC, REGFI_SK_REC, REGFI_DATA, and
+ * Can be used to free REGFI_NK, REGFI_VK, REGFI_SK, REGFI_DATA, and
  * REGFI_CLASSNAME records.
  *
